@@ -132,7 +132,7 @@ class CHGraph(object):
         if edge_con_list is not None and len(edge_con_list) > 0:
             edge_con_list_con = " and " + " and ".join(edge_con_list)
 
-        target_field_list_con = edge_info["rank"] + "," + edge_info["src"] + "," + edge_info["dst"]
+        target_field_list_con = edge_info["src"] + "," + edge_info["dst"] + "," + edge_info["rank"]
         if target_field_list is None:
             target_field_list_con += "," + ",".join(edge_info["fields"])
         elif type(target_field_list) == list and len(target_field_list) > 0:
@@ -630,7 +630,12 @@ class CHGraph(object):
                                                               edge_name_list, edge_con_list_list,
                                                               target_field_list, True, True)
         # f_edges_final, b_edges_final is list of datdaframe
-        [second_edges, third_edges_final] = self.find_path_multi_edge_s2(f_vertices.tolist(), end_vertex_list,
+        if isinstance(f_vertices, pd.DataFrame):
+            new_start_vertex_ids = f_vertices.tolist()
+        else:
+            new_start_vertex_ids = f_vertices
+        [second_edges, third_edges_final] = self.find_path_multi_edge_s2(new_start_vertex_ids,
+                                                                         end_vertex_list,
                                                                          edge_name_list,
                                                                          edge_con_list_list, target_field_list)
 
@@ -680,7 +685,11 @@ class CHGraph(object):
                                                               edge_name_list, edge_con_list_list,
                                                               target_field_list, True, True)
         # f_edges_final, b_edges_final is list of datdaframe
-        [second_edges, third_edges_final, fourth_edges_final] = self.find_path_multi_edge_s3(f_vertices.tolist(),
+        if isinstance(f_vertices, pd.DataFrame):
+            new_start_vertex_ids = f_vertices.tolist()
+        else:
+            new_start_vertex_ids = f_vertices
+        [second_edges, third_edges_final, fourth_edges_final] = self.find_path_multi_edge_s3(new_start_vertex_ids,
                                                                                              end_vertex_list,
                                                                                              edge_name_list,
                                                                                              edge_con_list_list,
@@ -747,11 +756,11 @@ class CHGraph(object):
                     db_table = subgraph_name + "." + edge_info["table"]
                     schema_fields = edge_info.get("fields")
                     if schema_fields:
-                        target_field_list_con = edge_info["rank"] + "," + edge_info["src"] + "," + \
-                                                edge_info["dst"] + "," + ",".join(schema_fields)
+                        target_field_list_con = edge_info["src"] + "," + edge_info["dst"] + "," + \
+                                                edge_info["rank"] + "," + ",".join(schema_fields)
                     else:
-                        target_field_list_con = edge_info["rank"] + "," + edge_info["src"] + "," + \
-                                                edge_info["dst"]
+                        target_field_list_con = edge_info["src"] + "," + edge_info["dst"] + "," + \
+                                                edge_info["rank"]
 
                     # TODO: list hurts performance and increases memory cost
                     col_list = [list(pd.to_datetime(single_res[i][col])) if str(
@@ -936,8 +945,8 @@ class CHGraph(object):
                         continue
                     edge_info = self.graph_cfg["edges"][edge_name_list[k]]
                     db_table = subgraph_name + "." + edge_info["table"]
-                    target_field_list_con = edge_info["src"] + "," + edge_info["dst"] + "," + ",".join(
-                        edge_info["fields"])
+                    target_field_list_con = edge_info["src"] + "," + edge_info["dst"] + "," + edge_info["rank"] + ","\
+                                            + ",".join(edge_info["fields"])
                     # TODO: list hurts performance and increases memory cost
                     # datetime64[ns] patch
                     # col_list = [list(res[i][k][col].values) for col in res[i][k].columns]
@@ -968,8 +977,8 @@ class CHGraph(object):
                             continue
                         edge_info = self.graph_cfg["edges"][edge_name_list[k]]
                         db_table = subgraph_name + "." + edge_info["table"]
-                        target_field_list_con = edge_info["src"] + "," + edge_info["dst"] + "," + ",".join(
-                            edge_info["fields"])
+                        target_field_list_con = edge_info["src"] + "," + edge_info["dst"] + "," + edge_info["rank"]\
+                                + "," + ",".join(edge_info["fields"])
                         # TODO: list hurts performance and increases memory cost
                         # datetime64[ns] patch
                         # col_list = [list(res[i][j][k][col].values) for col in res[i][j][k].columns]
